| Title: | R Driver for Apache Drill |
|---|---|
| Description: | Provides a R driver for Apache Drill<https://drill.apache.org>, which could connect to the Apache Drill cluster<https://drill.apache.org/docs/installing-drill-on-the-cluster> or drillbit<https://drill.apache.org/docs/embedded-mode-prerequisites> and get result(in data frame) from the SQL query and check the current configuration status. This link <https://drill.apache.org/docs> contains more information about Apache Drill. |
| Authors: | Hanbing Yang |
| Maintainer: | Hanbing Yang <[email protected]> |
| License: | GPL |
| Version: | 0.1 |
| Built: | 2026-05-13 09:14:51 UTC |
| Source: | https://github.com/cran/DrillR |
drill defines a Apache Drill driver class.Class drill defines a Apache Drill driver class.
hostA string denoting the Apache Drill cluster/node host
portA numeric denoting the Apache Drill cluster/node port
To show whether the connection is active.
rd_active(object) ## S4 method for signature 'drill' rd_active(object)rd_active(object) ## S4 method for signature 'drill' rd_active(object)
object |
the RDrill object |
#rd_active(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_active(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Show the information of the memory metrics.
rd_metrics(object) ## S4 method for signature 'drill' rd_metrics(object)rd_metrics(object) ## S4 method for signature 'drill' rd_metrics(object)
object |
the RDrill object |
#rd_metrics(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_metrics(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Show the information of the system and session options such as name and data type and so forth.
rd_options(object) ## S4 method for signature 'drill' rd_options(object)rd_options(object) ## S4 method for signature 'drill' rd_options(object)
object |
the RDrill object |
#rd_options(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_options(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Show the information about the running and completed queries.
rd_profiles(object) ## S4 method for signature 'drill' rd_profiles(object)rd_profiles(object) ## S4 method for signature 'drill' rd_profiles(object)
object |
the RDrill object |
#rd_profiles(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_profiles(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Submit a SQL query and return results as a data frame.
rd_query(object, sql) ## S4 method for signature 'drill' rd_query(object, sql)rd_query(object, sql) ## S4 method for signature 'drill' rd_query(object, sql)
object |
the RDrill object |
sql |
the query submitted |
#rd_query(R_DRILL_OBJECT,SQL_QUERY) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_query(R_DRILL_OBJECT,SQL_QUERY) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Show the information of Drillbits, their ports and hosts.
rd_stats(object) ## S4 method for signature 'drill' rd_stats(object)rd_stats(object) ## S4 method for signature 'drill' rd_stats(object)
object |
the RDrill object |
#rd_stats(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_stats(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Show the configurations of the storage plugins.
rd_storages(object) ## S4 method for signature 'drill' rd_storages(object)rd_storages(object) ## S4 method for signature 'drill' rd_storages(object)
object |
the RDrill object |
#rd_storages(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_storages(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Show the information of the threads status.
rd_threads(object) ## S4 method for signature 'drill' rd_threads(object)rd_threads(object) ## S4 method for signature 'drill' rd_threads(object)
object |
the RDrill object |
#rd_threads(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.#rd_threads(R_DRILL_OBJECT) #please replace 'R_DRILL_OBJECT' with your RDrill object.
Get the Apache Drill Connection, return the RDrill object.
rdrill(host, port) ## S4 method for signature 'character,numeric' rdrill(host, port)rdrill(host, port) ## S4 method for signature 'character,numeric' rdrill(host, port)
host |
Apache Drill cluster/node host |
port |
Apache Drill cluster/node port |
rdrill("127.0.0.1",8047)rdrill("127.0.0.1",8047)